@@ -2,7 +2,7 @@ package Catmandu::Cmd::breaker;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use parent 'Catmandu::Cmd';
 use Catmandu;
@@ -38,7 +38,7 @@ sub command {
             $tags = join "," , path($opts->fields)->lines_utf8({chomp =>1});
         }
         else {
-            $tags = $opts->tags;
+            $tags = $opts->fields;
         }
     }
     my $breaker = Catmandu::Breaker->new(
